@@ -1,4 +1,5 @@
-from bolinette.services.base import BaseService
+from bolinette.services.base import BaseService, SimpleService
 from bolinette.services.user import user_service
 from bolinette.services.role import role_service
 from bolinette.services.file import file_service
+from bolinette.services.timezone import timezone_service
